about summary refs log tree commit diff
path: root/nptl/sysdeps/unix/sysv/linux/x86_64/pthread_cond_broadcast.S
diff options
context:
space:
mode:
Diffstat (limited to 'nptl/sysdeps/unix/sysv/linux/x86_64/pthread_cond_broadcast.S')
-rw-r--r--nptl/sysdeps/unix/sysv/linux/x86_64/pthread_cond_broadcast.S8
1 files changed, 5 insertions, 3 deletions
diff --git a/nptl/sysdeps/unix/sysv/linux/x86_64/pthread_cond_broadcast.S b/nptl/sysdeps/unix/sysv/linux/x86_64/pthread_cond_broadcast.S
index 8e26681b3b..6d29d761fa 100644
--- a/nptl/sysdeps/unix/sysv/linux/x86_64/pthread_cond_broadcast.S
+++ b/nptl/sysdeps/unix/sysv/linux/x86_64/pthread_cond_broadcast.S
@@ -1,4 +1,4 @@
-/* Copyright (C) 2002, 2003 Free Software Foundation, Inc.
+/* Copyright (C) 2002, 2003, 2004 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
    Contributed by Ulrich Drepper <drepper@redhat.com>, 2002.
 
@@ -63,6 +63,8 @@ __pthread_cond_broadcast:
 	/* Cause all currently waiting threads to recognize they are
 	   woken up.  */
 	movq	%rcx, (%rdi)
+	movq	%rcx, woken_seq-wakeup_seq(%rdi)
+	incl	broadcast_seq-wakeup_seq(%rdi)
 
 	/* Get the address of the mutex used.  */
 	movq	dep_mutex-wakeup_seq(%rdi), %r8
@@ -110,12 +112,12 @@ __pthread_cond_broadcast:
 #endif
 	jmp	2b
 
 	/* Unlock in loop requires waekup.  */
 5:	addq	$cond_lock-wakeup_seq, %rdi
 	callq	__lll_mutex_unlock_wake
 	jmp	6b
 
 	/* Unlock in loop requires waekup.  */
 7:	addq	$cond_lock-wakeup_seq, %rdi
 	callq	__lll_mutex_unlock_wake
 	subq	$cond_lock-wakeup_seq, %rdi
@@ -110,12 +112,12 @@ __pthread_cond_broadcast:
 	jmp	2b
 
-	/* Unlock in loop requires waekup.  */
+	/* Unlock in loop requires wakeup.  */
 5:	addq	$cond_lock-wakeup_seq, %rdi
 	callq	__lll_mutex_unlock_wake
@@ -110,12 +112,12 @@ __pthread_cond_broadcast:
 	jmp	6b
 
-	/* Unlock in loop requires waekup.  */
+	/* Unlock in loop requires wakeup.  */
 7:	addq	$cond_lock-wakeup_seq, %rdi
 	callq	__lll_mutex_unlock_wake